#!/usr/bin/env python
"""Make sure filesystem isn't checked during reboots."""

import os
import subprocess
import re
import logging


def get_mounted_devices():
    """Get mounted devices according to mtab.

    :returns: Paths to mounted devices
    :rtype: list

    """
    logging.info('Getting mounted devices...')
    with open('/etc/mtab') as f:
        devices = []
        for line in f:
            device, mount_point = line.split()[:2]
            if os.path.exists(device):
                assert os.path.ismount(mount_point)
                devices.append(device)

    logging.info('Mounted devices: {}'
                 .format(', '.join([repr(d) for d in devices])))
    return devices


def get_maximum_mount_count(device):
    """Get maximum mount count for a given device.

    :param device: A path to a device file
    :type device: str
    :returns: Maximum mount count for the given device
    :rtype: int

    """
    logging.info('Getting maximum mount count for {!r}'.format(device))
    output = subprocess.check_output(['dumpe2fs', device])
    match = re.search('^Maximum mount count:\s+(-?\d+)', output, re.MULTILINE)
    assert match, "Maximum mount count not found"
    maximum_mount_count = int(match.group(1))
    logging.info('Maximum mount count for {!r}: {}'
                 .format(device, maximum_mount_count))
    return maximum_mount_count


def set_maximum_mount_count(device, count):
    """Set maximum mount count for a device.

    :param device: Path to device file
    :type device: str
    :param count: Count number to set the maximum number count to
    :type count: int

    """
    logging.info('Setting maximum mount count for {!r} to {}'
                 .format(device, count))
    subprocess.check_call(['tune2fs', '-c', str(count), device])


def main():
    devices = get_mounted_devices()
    for device in devices:
        maximum_mount_count = get_maximum_mount_count(device)
        if maximum_mount_count not in (0, -1):
            set_maximum_mount_count(device, 0)
            maximum_mount_count = get_maximum_mount_count(device)
            assert maximum_mount_count in (0, -1), \
                'Set maximum mount count operation failed'
    else:
        logging.info('No filesystem should be checked on reboot')


if __name__ == '__main__':
    logging.basicConfig(level=logging.NOTSET,
                        format='%(levelname)s: %(message)s')
    main()
